Exception: SQLite3::Exception
- Inherits:
-
StandardError
- Object
- StandardError
- SQLite3::Exception
- Defined in:
- lib/sqlite3/errors.rb
Direct Known Subclasses
AbortException, AuthorizationException, BusyException, CantOpenException, ConstraintException, CorruptException, EmptyException, FormatException, FullException, IOException, InternalException, InterruptException, LockedException, MemoryException, MismatchException, MisuseException, NotADatabaseException, NotFoundException, PermissionException, ProtocolException, RangeException, ReadOnlyException, SQLException, SchemaChangedException, TooBigException, UnsupportedException
Class Method Summary collapse
-
.code ⇒ Object
The numeric error code that this exception represents.
Instance Method Summary collapse
-
#code ⇒ Object
A convenience for accessing the error code for this exception.
Class Method Details
.code ⇒ Object
The numeric error code that this exception represents.
39 40 41 |
# File 'lib/sqlite3/errors.rb', line 39 def self.code @code end |
Instance Method Details
#code ⇒ Object
A convenience for accessing the error code for this exception.
44 45 46 |
# File 'lib/sqlite3/errors.rb', line 44 def code self.class.code end |