Class: SQLite3::ResultSet::ArrayWithTypesAndFields
- Inherits:
-
Array
- Object
- Array
- SQLite3::ResultSet::ArrayWithTypesAndFields
- Defined in:
- lib/sqlite3/resultset.rb
Overview
:nodoc:
Instance Attribute Summary collapse
Instance Attribute Details
#fields ⇒ Object
28 29 30 31 32 33 |
# File 'lib/sqlite3/resultset.rb', line 28 def fields warn("\#{caller[0]} is calling `\#{self.class}#fields` which is deprecated and will be removed in sqlite3 version 2.0.0. Please call the `columns` method on the SQLite3::ResultSet object that created this object.\n eowarn\n @fields\nend\n") if $VERBOSE |
#types ⇒ Object
21 22 23 24 25 26 |
# File 'lib/sqlite3/resultset.rb', line 21 def types warn("\#{caller[0]} is calling `\#{self.class}#types` which is deprecated and will be removed in sqlite3 version 2.0.0. Please call the `types` method on the SQLite3::ResultSet object that created this object.\n eowarn\n @types\nend\n") if $VERBOSE |