Method: Sqlite3::ExtConf.print_help

Defined in:
ext/sqlite3/extconf.rb


201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'ext/sqlite3/extconf.rb', line 201

def print_help
  print("    USAGE: ruby \#{$PROGRAM_NAME} [options]\n\n      Flags that are always valid:\n\n          --disable-system-libraries\n              Use the packaged libraries, and ignore the system libraries.\n              (This is the default behavior.)\n\n          --enable-system-libraries\n              Use system libraries instead of building and using the packaged libraries.\n\n          --with-sqlcipher\n              Use libsqlcipher instead of libsqlite3.\n              (Implies `--enable-system-libraries`.)\n\n          --with-sqlite-source-dir=DIRECTORY\n              (dev only) Build sqlite from the source code in DIRECTORY\n\n          --help\n              Display this message.\n\n\n      Flags only used when using system libraries:\n\n          General (applying to all system libraries):\n\n              --with-opt-dir=DIRECTORY\n                  Look for headers and libraries in DIRECTORY.\n\n              --with-opt-lib=DIRECTORY\n                  Look for libraries in DIRECTORY.\n\n              --with-opt-include=DIRECTORY\n                  Look for headers in DIRECTORY.\n\n          Related to sqlcipher:\n\n              --with-sqlcipher-dir=DIRECTORY\n                  Look for sqlcipher headers and library in DIRECTORY.\n                  (Implies `--with-sqlcipher` and `--enable-system-libraries`.)\n\n              --with-sqlcipher-lib=DIRECTORY\n                  Look for sqlcipher library in DIRECTORY.\n                  (Implies `--with-sqlcipher` and `--enable-system-libraries`.)\n\n              --with-sqlcipher-include=DIRECTORY\n                  Look for sqlcipher headers in DIRECTORY.\n                  (Implies `--with-sqlcipher` and `--enable-system-libraries`.)\n\n\n      Flags only used when building and using the packaged libraries:\n\n          --with-sqlite-cflags=CFLAGS\n              Explicitly pass compiler flags to the sqlite library build. These flags will\n              appear on the commandline before any flags set in the CFLAGS environment\n              variable. This is useful for setting compilation options in your project's\n              bundler config. See INSTALLATION.md for more information.\n\n          --enable-cross-build\n              Enable cross-build mode. (You probably do not want to set this manually.)\n\n\n      Environment variables used for compiling the gem's C extension:\n\n          CC\n              Use this path to invoke the compiler instead of `RbConfig::CONFIG['CC']`\n\n\n      Environment variables passed through to the compilation of sqlite:\n\n          CC\n          CPPFLAGS\n          CFLAGS\n          LDFLAGS\n          LIBS\n          LT_SYS_LIBRARY_PATH\n          CPP\n\n  TEXT\nend\n")