Method: SQLite3::Exception#sql_offset
- Defined in:
- lib/sqlite3/errors.rb
#sql_offset ⇒ Object (readonly)
If the error is associated with a particular offset in a SQL query, this is the non-negative offset. If the offset is not available, this will be -1.
13 14 15 |
# File 'lib/sqlite3/errors.rb', line 13 def sql_offset @sql_offset end |