Class: SQLite3::ResultSet
- Inherits:
-
Object
- Object
- SQLite3::ResultSet
- Includes:
- Enumerable
- Defined in:
- lib/sqlite3/resultset.rb
Overview
The ResultSet object encapsulates the enumerability of a query’s output. It is a simple cursor over the data that the query returns. It will very rarely (if ever) be instantiated directly. Instead, client’s should obtain a ResultSet instance via Statement#execute.
Defined Under Namespace
Classes: ArrayWithTypes, ArrayWithTypesAndFields, HashWithTypes
Instance Method Summary collapse
-
#close ⇒ Object
Closes the statement that spawned this result set.
-
#closed? ⇒ Boolean
Queries whether the underlying statement has been closed or not.
-
#columns ⇒ Object
Returns the names of the columns returned by this result set.
-
#each ⇒ Object
Required by the Enumerable mixin.
-
#eof? ⇒ Boolean
Query whether the cursor has reached the end of the result set or not.
-
#initialize(db, stmt, utf_16 = false) ⇒ ResultSet
constructor
Create a new ResultSet attached to the given database, using the given sql text.
-
#next ⇒ Object
Obtain the next row from the cursor.
-
#reset(*bind_params) ⇒ Object
Reset the cursor, so that a result set which has reached end-of-file can be rewound and reiterated.
-
#types ⇒ Object
Returns the types of the columns returned by this result set.
Constructor Details
#initialize(db, stmt, utf_16 = false) ⇒ ResultSet
Create a new ResultSet attached to the given database, using the given sql text.
63 64 65 66 67 68 69 |
# File 'lib/sqlite3/resultset.rb', line 63 def initialize(db, stmt, utf_16 = false) @db = db @driver = @db.driver @stmt = stmt @utf_16 = utf_16 commence end |
Instance Method Details
#close ⇒ Object
Closes the statement that spawned this result set. Use with caution! Closing a result set will automatically close any other result sets that were spawned from the same statement.
187 188 189 |
# File 'lib/sqlite3/resultset.rb', line 187 def close @stmt.close end |
#closed? ⇒ Boolean
Queries whether the underlying statement has been closed or not.
192 193 194 |
# File 'lib/sqlite3/resultset.rb', line 192 def closed? @stmt.closed? end |
#columns ⇒ Object
Returns the names of the columns returned by this result set.
202 203 204 |
# File 'lib/sqlite3/resultset.rb', line 202 def columns @stmt.columns end |
#each ⇒ Object
Required by the Enumerable mixin. Provides an internal iterator over the rows of the result set.
178 179 180 181 182 |
# File 'lib/sqlite3/resultset.rb', line 178 def each while row=self.next yield row end end |
#eof? ⇒ Boolean
Query whether the cursor has reached the end of the result set or not.
102 103 104 |
# File 'lib/sqlite3/resultset.rb', line 102 def eof? @eof end |
#next ⇒ Object
Obtain the next row from the cursor. If there are no more rows to be had, this will return nil. If type translation is active on the corresponding database, the values in the row will be translated according to their types.
The returned value will be an array, unless Database#results_as_hash has been set to true, in which case the returned value will be a hash.
For arrays, the column names are accessible via the fields property, and the column types are accessible via the types property.
For hashes, the column names are the keys of the hash, and the column types are accessible via the types property.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/sqlite3/resultset.rb', line 119 def next return nil if @eof @stmt.must_be_open! unless @first_row result = @driver.step(@stmt.handle) check result end @first_row = false unless @eof row = [] @driver.data_count(@stmt.handle).times do |column| type = @driver.column_type(@stmt.handle, column) if type == Constants::ColumnType::NULL row << nil elsif type == Constants::ColumnType::BLOB row << @driver.column_blob(@stmt.handle, column) elsif type == Constants::ColumnType::INTEGER row << @driver.column_int64(@stmt.handle, column) elsif type == Constants::ColumnType::FLOAT row << @driver.column_double(@stmt.handle, column) else row << @driver.column_text(@stmt.handle, column, @utf_16) end end # if @db.type_translation # row = @stmt.types.zip(row).map do |type, value| # @db.translator.translate(type, value) # end # end if @db.results_as_hash new_row = HashWithTypes[ *(@stmt.columns.zip(row).to_a.flatten) ] row.each_with_index { |value,idx| new_row[idx] = value } row = new_row else if row.respond_to?(:fields) row = ArrayWithTypes.new(row) else row = ArrayWithTypesAndFields.new(row) end row.fields = @stmt.columns end # row.types = @stmt.types return row end nil end |
#reset(*bind_params) ⇒ Object
Reset the cursor, so that a result set which has reached end-of-file can be rewound and reiterated.
92 93 94 95 96 97 98 99 |
# File 'lib/sqlite3/resultset.rb', line 92 def reset(*bind_params) @stmt.must_be_open! @stmt.reset!(false) @driver.reset(@stmt.handle) @stmt.bind_params(*bind_params) @eof = false commence end |
#types ⇒ Object
Returns the types of the columns returned by this result set.
197 198 199 |
# File 'lib/sqlite3/resultset.rb', line 197 def types @stmt.types end |